@@ -19,6 +19,7 @@ class TestingManager(BaseTestingManager):
         super().__init__(credentials)
 
         self.__config = config
+        self.__env = {**os.environ.copy(), **(self.credentials.environ or {})}
 
     def prepare_infrastructure(self) -> None:
         """
@@ -47,17 +48,17 @@ class TestingManager(BaseTestingManager):
 
     def __bootstrap_infrastructure(self) -> None:
         sub = ContinuousSubprocess(TestingManager.__aws_cdk_bootstrap_command())
-        output = sub.execute(path=self.__config.cdk_app_path, env={**os.environ.copy(), **self.credentials.environ})
+        output = sub.execute(path=self.__config.cdk_app_path, env=self.__env)
         for line in output: logger.info(line)
 
     def __create_infrastructure(self) -> None:
         sub = ContinuousSubprocess(TestingManager.__aws_cdk_deploy_command())
-        output = sub.execute(path=self.__config.cdk_app_path, env={**os.environ.copy(), **self.credentials.environ})
+        output = sub.execute(path=self.__config.cdk_app_path, env=self.__env)
         for line in output: logger.info(line)
 
     def __destroy_infrastructure(self) -> None:
         sub = ContinuousSubprocess(TestingManager.__aws_cdk_destroy_command())
-        output = sub.execute(path=self.__config.cdk_app_path, env={**os.environ.copy(), **self.credentials.environ})
+        output = sub.execute(path=self.__config.cdk_app_path, env=self.__env)
         for line in output: logger.info(line)
 
     """
